package com.fzm.portal.controller;

import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.dto.OrderDto;
import com.fzm.common.entity.vo.OrderVo;
import com.fzm.common.enums.OrderStatus;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.OrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

/**
 * @author tangtuo
 * @date 2022/1/20 18:22
 */
@Authentication
@Api(tags = "订单管理")
@RestController
@RequestMapping("/order")
public class OrderController {

    @Resource
    private OrderService orderService;


    @PostMapping("/create")
    @ApiOperation("下单")
    public ResponseModel<String> createOrder(@RequestBody OrderDto orderDto) {
        Long orderId = orderService.createOrder(orderDto);
        return ResponseModel.success(String.valueOf(orderId));
    }


    @GetMapping("/query-order-status/{orderId}")
    @ApiOperation(value = "查询订单状态")
    public ResponseModel<Integer> queryOrderStatus(@PathVariable Long orderId) {
        return ResponseModel.success(orderService.getById(orderId).getOrderStatus());
    }


    @PostMapping("/cancel")
    @ApiOperation("取消订单")
    public ResponseModel<Boolean> cancelOrder(@RequestParam Long orderId) {
        Boolean result = orderService.cancel(orderId, OrderStatus.CANCEL);
        return ResponseModel.success(result);
    }


    @GetMapping("/list/{payScene}")
    @ApiOperation(value = "获取我的订单列表")
    public ResponseModel<List<OrderVo>> listOrder(@PathVariable Integer payScene) {
        List<OrderVo> orders = orderService.listOrder(payScene);
        return ResponseModel.success(orders);
    }

    @PostMapping("/renew-order-status")
    @ApiOperation("更新订单状态")
    public ResponseModel<Boolean> renewOrderStatus(@RequestParam Long orderId) throws IOException, InterruptedException {
        return ResponseModel.success(orderService.renewOrderStatus(orderId));
    }

}
