package com.fzm.portal.schedule;

import cn.hutool.core.collection.CollectionUtil;
import com.fzm.common.entity.Order;
import com.fzm.common.enums.OrderStatus;
import com.fzm.common.enums.WxPayStatus;
import com.fzm.common.service.OrderService;
import com.fzm.common.service.RefundService;
import com.fzm.common.service.WxPayService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.redisson.Redisson;
import org.redisson.api.RLock;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @author tangtuo
 * @date 2022/2/8 15:31
 */
@Slf4j
@Component
public class PayTask {

    @Resource
    private OrderService orderService;

    @Resource
    private WxPayService wxPayService;

    @Resource
    private Redisson redisson;

    @Resource
    private RefundService refundService;

    /**
     * 定时关单的任务
     */
    @Scheduled(cron = "0 */1 * * * ?")
    public void closeOrder() throws InterruptedException {
        RLock lock = redisson.getLock("close-order");
        // 加锁,避免集群环境下多个节点同事运行此定时任务
        if (!lock.tryLock(30, TimeUnit.SECONDS)) {
            log.warn("此任务正在运行中");
            return;
        }
        // 查询超时(创建后超过24小时未支付)的订单
        List<Order> orderList = orderService.getTimeOutOrders(24);
        if (CollectionUtil.isEmpty(orderList)) {
            return;
        }
        for (Order order : orderList) {
            Long orderId = order.getId();
            try {
                // 确认订单状态
                String orderStatus = wxPayService.queryOrder(orderId);
                if (StringUtils.isBlank(orderStatus) || WxPayStatus.NOTPAY.getStatus().equals(orderStatus)) {
                    // 订单未支付,则关闭订单
                    orderService.cancel(orderId, OrderStatus.CLOSED);
                }
            } catch (Exception e) {
                log.error(String.format("订单状态更新失败,当前订单号: %s", orderId), e);
            }
        }
    }

}
